@@ -3,8 +3,7 @@ use crate::rbe_error::RbeError;
 use crate::Key;
 use crate::Ref;
 use crate::Value;
-use serde_derive::Deserialize;
-use serde_derive::Serialize;
+use serde::{Deserialize, Serialize};
 use std::fmt::Debug;
 use std::fmt::Display;
 use std::fmt::Formatter;
