@@ -6,7 +6,11 @@ pub mod rudof;
 pub mod rudof_config;
 pub mod rudof_error;
 pub mod shapes_graph_source;
+pub use oxrdf;
 pub use rudof::*;
 pub use rudof_config::*;
 pub use rudof_error::*;
+pub use shacl_ast;
+pub use shacl_validation;
 pub use shapes_graph_source::*;
+pub use srdf;
