@@ -6,17 +6,16 @@ use super::compile_shape;
 use super::compile_shapes;
 use super::compiled_shacl_error::CompiledShaclError;
 use super::convert_iri_ref;
-use super::convert_lang;
 use super::convert_value;
 use super::shape::CompiledShape;
 use iri_s::iri;
 use iri_s::IriS;
 use node_kind::NodeKind;
-use srdf::RDFNode;
-use srdf::SRDFBasic;
+use srdf::lang::Lang;
+use srdf::Rdf;
 
 #[derive(Debug)]
-pub enum CompiledComponent<S: SRDFBasic> {
+pub enum CompiledComponent<S: Rdf> {
     Class(Class<S>),
     Datatype(Datatype<S>),
     NodeKind(Nodekind),
@@ -30,7 +29,7 @@ pub enum CompiledComponent<S: SRDFBasic> {
     MaxLength(MaxLength),
     Pattern(Pattern),
     UniqueLang(UniqueLang),
-    LanguageIn(LanguageIn<S>),
+    LanguageIn(LanguageIn),
     Equals(Equals<S>),
     Disjoint(Disjoint<S>),
     LessThan(LessThan<S>),
@@ -46,11 +45,11 @@ pub enum CompiledComponent<S: SRDFBasic> {
     QualifiedValueShape(QualifiedValueShape<S>),
 }
 
-impl<S: SRDFBasic> CompiledComponent<S> {
+impl<S: Rdf> CompiledComponent<S> {
     pub fn compile(component: Component, schema: &Schema) -> Result<Self, CompiledShaclError> {
         let component = match component {
             Component::Class(object) => {
-                let class_rule = S::object_as_term(&object);
+                let class_rule = object.into();
                 CompiledComponent::Class(Class::new(class_rule))
             }
             Component::Datatype(iri_ref) => {
@@ -61,19 +60,23 @@ impl<S: SRDFBasic> CompiledComponent<S> {
             Component::MinCount(count) => CompiledComponent::MinCount(MinCount::new(count)),
             Component::MaxCount(count) => CompiledComponent::MaxCount(MaxCount::new(count)),
             Component::MinExclusive(literal) => {
-                let term = S::object_as_term(&RDFNode::literal(literal));
+                let literal: S::Literal = literal.clone().into();
+                let term = literal.into();
                 CompiledComponent::MinExclusive(MinExclusive::new(term))
             }
             Component::MaxExclusive(literal) => {
-                let term = S::object_as_term(&RDFNode::literal(literal));
+                let literal: S::Literal = literal.clone().into();
+                let term = literal.into();
                 CompiledComponent::MaxExclusive(MaxExclusive::new(term))
             }
             Component::MinInclusive(literal) => {
-                let term = S::object_as_term(&RDFNode::literal(literal));
+                let literal: S::Literal = literal.clone().into();
+                let term = literal.into();
                 CompiledComponent::MinInclusive(MinInclusive::new(term))
             }
             Component::MaxInclusive(literal) => {
-                let term = S::object_as_term(&RDFNode::literal(literal));
+                let literal: S::Literal = literal.clone().into();
+                let term = literal.into();
                 CompiledComponent::MaxInclusive(MaxInclusive::new(term))
             }
             Component::MinLength(length) => CompiledComponent::MinLength(MinLength::new(length)),
@@ -83,11 +86,7 @@ impl<S: SRDFBasic> CompiledComponent<S> {
             }
             Component::UniqueLang(lang) => CompiledComponent::UniqueLang(UniqueLang::new(lang)),
             Component::LanguageIn { langs } => {
-                let literals = langs
-                    .into_iter()
-                    .map(|lang| convert_lang::<S>(lang))
-                    .collect::<Result<Vec<_>, _>>()?;
-                CompiledComponent::LanguageIn(LanguageIn::new(literals))
+                CompiledComponent::LanguageIn(LanguageIn::new(langs))
             }
             Component::Equals(iri_ref) => {
                 let iri_ref = convert_iri_ref::<S>(iri_ref)?;
@@ -215,11 +214,11 @@ impl MinCount {
 ///
 /// https://www.w3.org/TR/shacl/#AndConstraintComponent
 #[derive(Debug)]
-pub struct And<S: SRDFBasic> {
+pub struct And<S: Rdf> {
     shapes: Vec<CompiledShape<S>>,
 }
 
-impl<S: SRDFBasic> And<S> {
+impl<S: Rdf> And<S> {
     pub fn new(shapes: Vec<CompiledShape<S>>) -> Self {
         And { shapes }
     }
@@ -234,11 +233,11 @@ impl<S: SRDFBasic> And<S> {
 ///
 /// https://www.w3.org/TR/shacl/#NotConstraintComponent
 #[derive(Debug)]
-pub struct Not<S: SRDFBasic> {
+pub struct Not<S: Rdf> {
     shape: CompiledShape<S>,
 }
 
-impl<S: SRDFBasic> Not<S> {
+impl<S: Rdf> Not<S> {
     pub fn new(shape: CompiledShape<S>) -> Self {
         Not { shape }
     }
@@ -255,11 +254,11 @@ impl<S: SRDFBasic> Not<S> {
 /// https://www.w3.org/TR/shacl/#AndConstraintComponent
 
 #[derive(Debug)]
-pub struct Or<S: SRDFBasic> {
+pub struct Or<S: Rdf> {
     shapes: Vec<CompiledShape<S>>,
 }
 
-impl<S: SRDFBasic> Or<S> {
+impl<S: Rdf> Or<S> {
     pub fn new(shapes: Vec<CompiledShape<S>>) -> Self {
         Or { shapes }
     }
@@ -275,11 +274,11 @@ impl<S: SRDFBasic> Or<S> {
 ///
 /// https://www.w3.org/TR/shacl/#XoneConstraintComponent
 #[derive(Debug)]
-pub struct Xone<S: SRDFBasic> {
+pub struct Xone<S: Rdf> {
     shapes: Vec<CompiledShape<S>>,
 }
 
-impl<S: SRDFBasic> Xone<S> {
+impl<S: Rdf> Xone<S> {
     pub fn new(shapes: Vec<CompiledShape<S>>) -> Self {
         Xone { shapes }
     }
@@ -301,12 +300,12 @@ impl<S: SRDFBasic> Xone<S> {
 ///
 /// https://www.w3.org/TR/shacl/#ClosedConstraintComponent
 #[derive(Debug)]
-pub struct Closed<S: SRDFBasic> {
+pub struct Closed<S: Rdf> {
     is_closed: bool,
     ignored_properties: Vec<S::IRI>,
 }
 
-impl<S: SRDFBasic> Closed<S> {
+impl<S: Rdf> Closed<S> {
     pub fn new(is_closed: bool, ignored_properties: Vec<S::IRI>) -> Self {
         Closed {
             is_closed,
@@ -328,11 +327,11 @@ impl<S: SRDFBasic> Closed<S> {
 ///
 /// https://www.w3.org/TR/shacl/#HasValueConstraintComponent
 #[derive(Debug)]
-pub struct HasValue<S: SRDFBasic> {
+pub struct HasValue<S: Rdf> {
     value: S::Term,
 }
 
-impl<S: SRDFBasic> HasValue<S> {
+impl<S: Rdf> HasValue<S> {
     pub fn new(value: S::Term) -> Self {
         HasValue { value }
     }
@@ -347,11 +346,11 @@ impl<S: SRDFBasic> HasValue<S> {
 ///
 /// https://www.w3.org/TR/shacl/#InConstraintComponent
 #[derive(Debug)]
-pub struct In<S: SRDFBasic> {
+pub struct In<S: Rdf> {
     values: Vec<S::Term>,
 }
 
-impl<S: SRDFBasic> In<S> {
+impl<S: Rdf> In<S> {
     pub fn new(values: Vec<S::Term>) -> Self {
         In { values }
     }
@@ -367,11 +366,11 @@ impl<S: SRDFBasic> In<S> {
 ///
 /// https://www.w3.org/TR/shacl/#DisjointConstraintComponent
 #[derive(Debug)]
-pub struct Disjoint<S: SRDFBasic> {
+pub struct Disjoint<S: Rdf> {
     iri_ref: S::IRI,
 }
 
-impl<S: SRDFBasic> Disjoint<S> {
+impl<S: Rdf> Disjoint<S> {
     pub fn new(iri_ref: S::IRI) -> Self {
         Disjoint { iri_ref }
     }
@@ -387,11 +386,11 @@ impl<S: SRDFBasic> Disjoint<S> {
 ///
 /// https://www.w3.org/TR/shacl/#EqualsConstraintComponent
 #[derive(Debug)]
-pub struct Equals<S: SRDFBasic> {
+pub struct Equals<S: Rdf> {
     iri_ref: S::IRI,
 }
 
-impl<S: SRDFBasic> Equals<S> {
+impl<S: Rdf> Equals<S> {
     pub fn new(iri_ref: S::IRI) -> Self {
         Equals { iri_ref }
     }
@@ -409,11 +408,11 @@ impl<S: SRDFBasic> Equals<S> {
 ///
 /// https://www.w3.org/TR/shacl/#LessThanOrEqualsConstraintComponent
 #[derive(Debug)]
-pub struct LessThanOrEquals<S: SRDFBasic> {
+pub struct LessThanOrEquals<S: Rdf> {
     iri_ref: S::IRI,
 }
 
-impl<S: SRDFBasic> LessThanOrEquals<S> {
+impl<S: Rdf> LessThanOrEquals<S> {
     pub fn new(iri_ref: S::IRI) -> Self {
         LessThanOrEquals { iri_ref }
     }
@@ -429,11 +428,11 @@ impl<S: SRDFBasic> LessThanOrEquals<S> {
 ///
 /// https://www.w3.org/TR/shacl/#LessThanConstraintComponent
 #[derive(Debug)]
-pub struct LessThan<S: SRDFBasic> {
+pub struct LessThan<S: Rdf> {
     iri_ref: S::IRI,
 }
 
-impl<S: SRDFBasic> LessThan<S> {
+impl<S: Rdf> LessThan<S> {
     pub fn new(iri_ref: S::IRI) -> Self {
         LessThan { iri_ref }
     }
@@ -448,11 +447,11 @@ impl<S: SRDFBasic> LessThan<S> {
 ///
 /// https://www.w3.org/TR/shacl/#NodeShapeComponent
 #[derive(Debug)]
-pub struct Node<S: SRDFBasic> {
+pub struct Node<S: Rdf> {
     shape: CompiledShape<S>,
 }
 
-impl<S: SRDFBasic> Node<S> {
+impl<S: Rdf> Node<S> {
     pub fn new(shape: CompiledShape<S>) -> Self {
         Node { shape }
     }
@@ -471,14 +470,14 @@ impl<S: SRDFBasic> Node<S> {
 ///
 /// https://www.w3.org/TR/shacl/#QualifiedValueShapeConstraintComponent
 #[derive(Debug)]
-pub struct QualifiedValueShape<S: SRDFBasic> {
+pub struct QualifiedValueShape<S: Rdf> {
     shape: CompiledShape<S>,
     qualified_min_count: Option<isize>,
     qualified_max_count: Option<isize>,
     qualified_value_shapes_disjoint: Option<bool>,
 }
 
-impl<S: SRDFBasic> QualifiedValueShape<S> {
+impl<S: Rdf> QualifiedValueShape<S> {
     pub fn new(
         shape: CompiledShape<S>,
         qualified_min_count: Option<isize>,
@@ -515,16 +514,16 @@ impl<S: SRDFBasic> QualifiedValueShape<S> {
 ///
 /// https://www.w3.org/TR/shacl/#LanguageInConstraintComponent
 #[derive(Debug)]
-pub struct LanguageIn<S: SRDFBasic> {
-    langs: Vec<S::Literal>,
+pub struct LanguageIn {
+    langs: Vec<Lang>,
 }
 
-impl<S: SRDFBasic> LanguageIn<S> {
-    pub fn new(langs: Vec<S::Literal>) -> Self {
+impl LanguageIn {
+    pub fn new(langs: Vec<Lang>) -> Self {
         LanguageIn { langs }
     }
 
-    pub fn langs(&self) -> &Vec<S::Literal> {
+    pub fn langs(&self) -> &Vec<Lang> {
         &self.langs
     }
 }
@@ -617,11 +616,11 @@ impl UniqueLang {
 ///
 /// https://www.w3.org/TR/shacl/#ClassConstraintComponent
 #[derive(Debug)]
-pub struct Class<S: SRDFBasic> {
+pub struct Class<S: Rdf> {
     class_rule: S::Term,
 }
 
-impl<S: SRDFBasic> Class<S> {
+impl<S: Rdf> Class<S> {
     pub fn new(class_rule: S::Term) -> Self {
         Class { class_rule }
     }
@@ -636,11 +635,11 @@ impl<S: SRDFBasic> Class<S> {
 ///
 /// https://www.w3.org/TR/shacl/#ClassConstraintComponent
 #[derive(Debug)]
-pub struct Datatype<S: SRDFBasic> {
+pub struct Datatype<S: Rdf> {
     datatype: S::IRI,
 }
 
-impl<S: SRDFBasic> Datatype<S> {
+impl<S: Rdf> Datatype<S> {
     pub fn new(datatype: S::IRI) -> Self {
         Datatype { datatype }
     }
@@ -671,11 +670,11 @@ impl Nodekind {
 
 /// https://www.w3.org/TR/shacl/#MaxExclusiveConstraintComponent
 #[derive(Debug)]
-pub struct MaxExclusive<S: SRDFBasic> {
+pub struct MaxExclusive<S: Rdf> {
     max_exclusive: S::Term,
 }
 
-impl<S: SRDFBasic> MaxExclusive<S> {
+impl<S: Rdf> MaxExclusive<S> {
     pub fn new(literal: S::Term) -> Self {
         MaxExclusive {
             max_exclusive: literal,
@@ -689,11 +688,11 @@ impl<S: SRDFBasic> MaxExclusive<S> {
 
 /// https://www.w3.org/TR/shacl/#MaxInclusiveConstraintComponent
 #[derive(Debug)]
-pub struct MaxInclusive<S: SRDFBasic> {
+pub struct MaxInclusive<S: Rdf> {
     max_inclusive: S::Term,
 }
 
-impl<S: SRDFBasic> MaxInclusive<S> {
+impl<S: Rdf> MaxInclusive<S> {
     pub fn new(literal: S::Term) -> Self {
         MaxInclusive {
             max_inclusive: literal,
@@ -707,11 +706,11 @@ impl<S: SRDFBasic> MaxInclusive<S> {
 
 /// https://www.w3.org/TR/shacl/#MinExclusiveConstraintComponent
 #[derive(Debug)]
-pub struct MinExclusive<S: SRDFBasic> {
+pub struct MinExclusive<S: Rdf> {
     min_exclusive: S::Term,
 }
 
-impl<S: SRDFBasic> MinExclusive<S> {
+impl<S: Rdf> MinExclusive<S> {
     pub fn new(literal: S::Term) -> Self {
         MinExclusive {
             min_exclusive: literal,
@@ -725,11 +724,11 @@ impl<S: SRDFBasic> MinExclusive<S> {
 
 /// https://www.w3.org/TR/shacl/#MinInclusiveConstraintComponent
 #[derive(Debug)]
-pub struct MinInclusive<S: SRDFBasic> {
+pub struct MinInclusive<S: Rdf> {
     min_inclusive: S::Term,
 }
 
-impl<S: SRDFBasic> MinInclusive<S> {
+impl<S: Rdf> MinInclusive<S> {
     pub fn new(literal: S::Term) -> Self {
         MinInclusive {
             min_inclusive: literal,
@@ -741,7 +740,7 @@ impl<S: SRDFBasic> MinInclusive<S> {
     }
 }
 
-impl<S: SRDFBasic> From<&CompiledComponent<S>> for IriS {
+impl<S: Rdf> From<&CompiledComponent<S>> for IriS {
     fn from(value: &CompiledComponent<S>) -> Self {
         match value {
             CompiledComponent::Class(_) => iri!(SH_CLASS_STR),
