@@ -1,8 +1,8 @@
 use shacl_ast::compiled::schema::CompiledSchema;
 use shacl_ast::ShaclParser;
 use srdf::RDFFormat;
+use srdf::Rdf;
 use srdf::ReaderMode;
-use srdf::SRDFBasic;
 use srdf::SRDFGraph;
 use std::io::BufRead;
 
@@ -18,7 +18,7 @@ pub trait Store<S> {
 pub struct ShaclDataManager;
 
 impl ShaclDataManager {
-    pub fn load<S: SRDFBasic, R: BufRead>(
+    pub fn load<S: Rdf, R: BufRead>(
         reader: R,
         rdf_format: RDFFormat,
         base: Option<&str>,
