@@ -1,9 +1,7 @@
 use std::{result, str::FromStr};
 
 use crate::ast::serde_string_or_struct::*;
-use serde::{Serialize as SerializeTrait, Serializer};
-use serde_derive::Deserialize;
-use serde_derive::Serialize;
+use serde::{Deserialize, Serialize, Serializer};
 use void::Void;
 
 #[derive(Deserialize, Serialize, Debug, PartialEq, Clone)]
