@@ -1,6 +1,6 @@
 use iri_s::IriS;
 use rbe::Value;
-use serde_derive::Serialize;
+use serde::Serialize;
 use srdf::numeric_literal::NumericLiteral;
 use srdf::Object;
 use std::fmt::Display;
